<button class="btn btn-info dropdown-toggle" type="button" data-bs-toggle="dropdown" data-bs-auto-close="false" aria-expanded="false">
  <span class="fa fa-download"></span> Download all regression logs
</button>
<div class="dropdown-menu p-4">
  <code><pre>wget -qO - <%= base_url %>/experiments/<%= @experiment.id %>/regression-logs/ \
  | xargs -n 2 wget --header='Accept: text/plain' -O</pre></code>
</div>
