<nav aria-label="breadcrumb">
  <ol class='breadcrumb'>
    <li class="breadcrumb-item"><a href='../'>Experiments</a></li>
    <li class="breadcrumb-item active">#<%= @experiment.id %> </li>
  </ol>
</nav>

<h1>Experiment #<%= @experiment.id %>: <%= @experiment.title %></h1>

<% if @percent_completed.positive? %>
  <div class="progress mb-4 mt-4" role="progressbar" aria-label="Experiment completion" aria-valuenow="<%= @percent_completed.round %>" aria-valuemin="0" aria-valuemax="100">
    <div class="progress-bar progress-bar-striped bg-success" style="width: <%= @percent_completed.round %>%">
      <%= @percent_completed.round %>%
    </div>
  </div>
<% end %>

<div class="mb-4">
  <%== erb(:experiment_download_regressions) %>
  <a class="btn btn-info" href="regressions/"><span class="fa fa-exclamation-circle"></span> Regressions</a>
</div>

<%== erb(:experiment_list_tests) %>
