module Debci
  module Runner
    class Base
      attr_reader :job

      def initialize(job)
        @job = job
      end

      def select_backend
        raise NotImplementedError.new
      end

      def submit
        raise NotImplementedError.new
      end
    end
  end
end
