<nav aria-label="breadcrumb">
  <ol class='breadcrumb'>
    <li class="breadcrumb-item"><a href='../../'>Experiments</a></li>
    <li class="breadcrumb-item"><a href="../"><%= @experiment.id %></a></li>
    <li class="breadcrumb-item active">Regressions</li>
  </ol>
</nav>

<h1>Experiment #<%= @experiment.id %>: <%= @experiment.title %></h1>

<div>
  <%== erb(:experiment_download_regressions) %>
</div>

<%== erb(:experiment_list_tests) %>
