require 'spec_helper'
require 'debci/job'
require 'debci/runner/base'

describe Debci::Runner::Base do
  let(:job) { Debci::Job.new }
  let(:runner) { Debci::Runner::Base.new(job) }

  it 'stores a reference to the job' do
    expect(runner.job).to be(job)
  end

  [
    :submit,
    :select_backend,
  ].each do |m|
    it "does not implement ##{m}" do
      expect { runner.send(m) }.to raise_error(NotImplementedError)
    end
  end
end
